@@ -93,26 +93,6 @@ gl_event_view_row_get_category_label (GlEventViewRow *row)
     return priv->category_label;
 }
 
-GtkWidget *
-gl_event_view_row_get_message_label (GlEventViewRow *row)
-{
-    GlEventViewRowPrivate *priv;
-
-    priv = gl_event_view_row_get_instance_private (row);
-
-    return priv->message_label;
-}
-
-GtkWidget *
-gl_event_view_row_get_time_label (GlEventViewRow *row)
-{
-    GlEventViewRowPrivate *priv;
-
-    priv = gl_event_view_row_get_instance_private (row);
-
-    return priv->time_label;
-}
-
 static void
 gl_event_view_row_finalize (GObject *object)
 {
